@@ -106,7 +106,7 @@ impl ServiceClient {
                     .into_iter()
                     .map(|id| id.to_string())
                     .collect::<Vec<_>>()
-                    .join(" ")
+                    .join(",")
             );
         }
 
